@@ -20,5 +20,10 @@ pub fn features() -> String {
     } else {
         features += "-m3u ";
     }
+    if cfg!(feature = "m4a") {
+        features += "+m4a ";
+    } else {
+        features += "-m4a ";
+    }
     features
 }
